@@ -404,7 +404,7 @@ int main(argc, argv)
      }
      XtGetApplicationNameAndClass(gv_display,&gv_name,&gv_class);
      SMESSAGE(gv_name) SMESSAGE(gv_class)
-     gv_database=XtDatabase(gv_display);
+
    }
 
    /*### Manage GNU command line arguments ########################*/
@@ -589,13 +589,13 @@ int main(argc, argv)
      }
 
    /*### getting resources ############################################*/
+   gv_database = resource_buildDatabase (XtDatabase(gv_display),
+                                         gv_display,
+                                         gv_class,
+                                         gv_name,
+                                         &argc,argv);
+   XrmSetDatabase (gv_display, gv_database);
 
-   {
-     XrmDatabase db;
-     INFMESSAGE(getting resources)
-     db = resource_buildDatabase(gv_display,gv_class,gv_name,&argc,argv);
-     XrmCombineDatabase(db,&gv_database,False);
-   }
 
 /*### initializing widget set and creating application shell #########################*/
 
@@ -1033,8 +1033,7 @@ int main(argc, argv)
             XtSetArg(args[n], XtNinterpreter,gv_gs_interpreter);	n++;
             b = gv_gs_safer ? True : False;
             XtSetArg(args[n], XtNsafer,b);                              n++;
-            b = gv_gs_quiet ? True : False;
-            XtSetArg(args[n], XtNquiet,b);                              n++;
+            XtSetArg(args[n], XtNquiet, True);                          n++;
             b = app_res.use_bpixmap ? True : False;
             XtSetArg(args[n], XtNuseBackingPixmap,b);                   n++;
             XtSetArg(args[n], XtNarguments,gv_gs_arguments);            n++;
