@@ -63,19 +63,10 @@
 
 #include "config.h"
 
-extern int pdf_delaysafer_hack;
-
 #include <stdio.h>
 #include <stdlib.h>
 
-#ifdef VMS
-#   include <unixio.h>
-#   include "strcasecmp.h"
-#   define unlink remove
-#   define USE_FTELL_FOR_FILEPOS
-#else
-#   include <string.h>
-#endif
+#include <string.h>
 
 #ifndef SEEK_SET
 #define SEEK_SET 0
@@ -195,7 +186,7 @@ static int      ps_io_ftell PT((FileData));
 
 static char    *readline PT((FileData, char **, long *, unsigned int *));
 static char    *gettextline PT((char *));
-static char    *gettext PT((char *,char **));
+static char    *ps_gettext PT((char *,char **));
 static int      blank PT((char *));
 static char    *pscopyuntil PT((FileData,FILE *,long,long,char *));
 
@@ -315,62 +306,6 @@ static char    *empty_string = "";
  *    installed a wing from a DC-2.
  */
 
-#ifndef VMS
-#  define ps_system system
-#else
-
-/*############################################################
- * ps_system        (VMS only, otherwise same as system())
- * Similar to system(), except it allows I/O redirection with <in >out
- * at the end of the line, and returns a more Unix-compatible status (0=OK).
- * The I/O redirection is very rudimentary. >> and | are NOT supported.
- * No error checking is performed, though hopefully the command will return
- * a reasonable error message when it can't access the file.
- * < or > in the command (eg. in directory spec), unless followed by another
- * < or >, will always be interpreted as I/O redirection, so be careful!
- *############################################################*/
-
-int ps_system(cmd)
-  char *cmd;
-{
-  char *inpf=NULL,*outf=NULL,*cf=NULL,*s,*t;
-  int status;
-
-  if (!cmd) cmd="";
-  cmd = PS_XtNewString(cmd);
-  s = strrchr(cmd,'>'); if (s) { outf = s+1; *s='\n'; }
-  s = strrchr(cmd,'<'); if (s) { inpf = s+1; *s='\n'; }
-  while ((s=strrchr(cmd,'\n'))) *s='\0';
-  if (outf) {
-    for (s=t=outf; *s; s++) if (!isspace(*s)) *t++=*s; 
-    *t='\0';
-    if (!(*outf)) outf=NULL;
-  }
-  if (inpf) {
-    for (s=t=inpf; *s; s++) if (!isspace(*s)) *t++=*s;
-    *t='\0';
-    if (!(*inpf)) inpf=NULL;
-  }
-  if (outf || inpf) {
-    FILE *com;
-    cf=file_getTmpFilename (NULL, outf ? outf : inpf);
-    com=fopen(cf, "w");
-    if (!com) return 1;
-    if (inpf) fprintf(com, "$DEFINE_/NOLOG SYS$INPUT  %s\n",inpf);
-    if (outf) fprintf(com, "$DEFINE_/NOLOG SYS$OUTPUT %s\n",outf);
-    fprintf(com,"$%s\n",cmd);
-    fclose(com);
-    PS_XtFree(cmd);
-    cmd = PS_XtMalloc((1+strlen(cf)+1)*sizeof(char));
-    sprintf(cmd,"@%s",cf);
-  }
-  status=system(cmd);
-  if (cf) unlink(cf);
-  PS_XtFree(cmd);
-  return((status&7)==1 ? 0 : status);
-}
-#endif
-
 /*-----------------------------------------------------------*/
 
 static void ps_dynMemExhaust()
@@ -417,7 +352,7 @@ psscan(fileP,filename,filename_raw,filename_dscP,cmd_scan_pdf,filename_uncP,cmd_
     long beginsection;		/* Position of the beginning of the section */
     unsigned int line_len; 	/* Length of the current line */
     unsigned int section_len;	/* Place to accumulate the section length */
-    char *next_char;		/* 1st char after text returned by gettext() */
+    char *next_char;		/* 1st char after text returned by ps_gettext() */
     char *cp;
     Media dmp;
     FileData fd;
@@ -453,21 +388,26 @@ psscan(fileP,filename,filename_raw,filename_dscP,cmd_scan_pdf,filename_uncP,cmd_
       struct document *retval = NULL;
       FILE *tmpfile = (FILE*)NULL;
       char *filename_unc;
+      char *quoted_filename, *quoted_filename_unc;
       char cmd[512];
       char s[512];
       mode_t old_umask;
       filename_unc=file_getTmpFilename(NULL,filename_raw);
+      quoted_filename = quote_filename(filename);
+      quoted_filename_unc = quote_filename(filename_unc);
       if (memcmp(b, "BZh", 3) == 0) {
-        sprintf(cmd, "bzip2 -dc %s >%s", filename, filename_unc);
+        sprintf(cmd, "bzip2 -dc %s >%s", quoted_filename, quoted_filename_unc);
       } else {
-        sprintf(cmd, "gzip -dc %s >%s", filename, filename_unc);
+        sprintf(cmd, "gzip -dc %s >%s", quoted_filename, quoted_filename_unc);
       }
+      GV_XtFree(quoted_filename);
+      GV_XtFree(quoted_filename_unc);
 
       old_umask = umask(0077);
 
       INFMESSAGE(is compressed)
       INFSMESSAGE(uncompress command,cmd)
-      if (ps_system(cmd) || file_fileIsNotUseful(filename_unc)) {
+      if (system(cmd) || file_fileIsNotUseful(filename_unc)) {
 	INFMESSAGE(uncompressing failed)
 unc_exec_failed:
 	sprintf(s,"Execution of\n%s\nfailed.",cmd);
@@ -532,25 +472,46 @@ unc_ok:
       section_len = line_len;
     } else if (iscomment(line,"%PDF-") && cmd_scan_pdf) {
       
-      /* PDF hack to set DELAYSAFER on interpreter invocation */
-      pdf_delaysafer_hack = 1;
-
       struct document *retval = NULL;
       FILE *tmpfile = (FILE*)NULL;
       char *filename_dsc;
+      char *quoted_filename, *quoted_filename_dsc;
+      char *pdfpos;
+      char *dscpos;
       char cmd[512];
       char s[512];
       mode_t old_umask;
+
       filename_dsc=file_getTmpFilename(NULL,filename_raw);
-      sprintf(cmd,cmd_scan_pdf,filename,filename_dsc);
+      /*      sprintf(cmd,cmd_scan_pdf,filename,filename_dsc); */
+      quoted_filename = quote_filename(filename);
+      quoted_filename_dsc = quote_filename(filename_dsc);
+      if ((pdfpos = strstr(cmd_scan_pdf,"%pdf")) &&
+	  (dscpos = strstr(cmd_scan_pdf,"%dsc"))) {
+	cmd[0] = '\0';
+	if (pdfpos < dscpos) {
+	  strncat(cmd,cmd_scan_pdf,(pdfpos-cmd_scan_pdf));
+	  strcat(cmd,quoted_filename);
+	  strncat(cmd,pdfpos+4,(dscpos-pdfpos-4));
+	  strcat(cmd,quoted_filename_dsc);
+	  strcat(cmd,dscpos+4);
+	} else {
+	  strncat(cmd,cmd_scan_pdf,(dscpos-cmd_scan_pdf));
+	  strcat(cmd,quoted_filename_dsc);
+	  strncat(cmd,dscpos+4,(pdfpos-dscpos-4));
+	  strcat(cmd,quoted_filename);
+	  strcat(cmd,pdfpos+4);
+	}
+      } else {
+	sprintf(cmd,cmd_scan_pdf,quoted_filename,quoted_filename_dsc);
+      }
+      GV_XtFree(quoted_filename);
+      GV_XtFree(quoted_filename_dsc);
+
       old_umask = umask(0077);
       INFMESSAGE(is PDF)
       INFSMESSAGE(scan command,cmd)
-#ifdef VMS
-      if ((system(cmd)&7)!=1 || file_fileIsNotUseful(filename_dsc)) {
-#else
       if (system(cmd) || file_fileIsNotUseful(filename_dsc)) {
-#endif
 	INFMESSAGE(scan subprocess failed)
 scan_exec_failed:
 	sprintf(s,"Execution of\n%s\nfailed.",cmd);
@@ -689,8 +650,8 @@ scan_ok:
 	    doc->media = (Media)
 			 PS_malloc(sizeof (MediaStruct));
             CHECK_MALLOCED(doc->media);
-	    doc->media[0].name = gettext(line+length("%%DocumentMedia:"),
-					 &next_char);
+	    doc->media[0].name = ps_gettext(line+length("%%DocumentMedia:"),
+					    &next_char);
 	    if (doc->media[0].name != NULL) {
 		if (sscanf(next_char, "%f %f", &w, &h) == 2) {
 		    doc->media[0].width = w + 0.5;
@@ -710,8 +671,8 @@ scan_ok:
 				     (doc->nummedia+1)*
 				     sizeof (MediaStruct));
                 CHECK_MALLOCED(doc->media);
-		doc->media[doc->nummedia].name = gettext(line+length("%%+"),
-							 &next_char);
+		doc->media[doc->nummedia].name = ps_gettext(line+length("%%+"),
+							    &next_char);
 		if (doc->media[doc->nummedia].name != NULL) {
 		    if (sscanf(next_char, "%f %f", &w, &h) == 2) {
 			doc->media[doc->nummedia].width = w + 0.5;
@@ -731,8 +692,8 @@ scan_ok:
 	    doc->media = (Media)
 			 PS_malloc(sizeof (MediaStruct));
             CHECK_MALLOCED(doc->media);
-	    doc->media[0].name = gettext(line+length("%%DocumentPaperSizes:"),
-					 &next_char);
+	    doc->media[0].name = ps_gettext(line+length("%%DocumentPaperSizes:"),
+					    &next_char);
 	    if (doc->media[0].name != NULL) {
 		doc->media[0].width = 0;
 		doc->media[0].height = 0;
@@ -757,7 +718,7 @@ scan_ok:
 		else
 		    PS_free(doc->media[0].name);
 	    }
-	    while ((cp = gettext(next_char, &next_char))) {
+	    while ((cp = ps_gettext(next_char, &next_char))) {
 		doc->media = (Media)
 			     PS_realloc(doc->media,
 				     (doc->nummedia+1)*
@@ -794,7 +755,7 @@ scan_ok:
 		   DSCcomment(line) && iscomment(line+2, "+")) {
 		section_len += line_len;
 		next_char = line + length("%%+");
-		while ((cp = gettext(next_char, &next_char))) {
+		while ((cp = ps_gettext(next_char, &next_char))) {
 		    doc->media = (Media)
 				 PS_realloc(doc->media,
 					 (doc->nummedia+1)*
@@ -884,7 +845,7 @@ scan_ok:
 		}
 	    } else if (page_media_set == NONE &&
 		       iscomment(line+2, "PageMedia:")) {
-		cp = gettext(line+length("%%PageMedia:"), NULL);
+		cp = ps_gettext(line+length("%%PageMedia:"), NULL);
 		for (dmp = doc->media, i=0; i<doc->nummedia; i++, dmp++) {
 		    if (strcmp(cp, dmp->name) == 0) {
 			doc->default_page_media = dmp;
@@ -1006,7 +967,7 @@ scan_ok:
 		}
 	    } else if (page_media_set == NONE &&
 		       iscomment(line+2, "PaperSize:")) {
-		cp = gettext(line+length("%%PaperSize:"), NULL);
+		cp = ps_gettext(line+length("%%PaperSize:"), NULL);
 		for (dmp = doc->media, i=0; i<doc->nummedia; i++, dmp++) {
 		    /* Note: Paper size comment uses down cased paper size
 		     * name.  Case insensitive compares are only used for
@@ -1096,7 +1057,7 @@ newpage:
 	    doc->pages = (struct page *) PS_calloc(maxpages, sizeof(struct page));
             CHECK_MALLOCED(doc->pages);
 	}
-	label = gettext(line+length("%%Page:"), &next_char);
+	label = ps_gettext(line+length("%%Page:"), &next_char);
 	if (sscanf(next_char, "%d", &thispage) != 1) thispage = 0;
 	if (nextpage == 1) {
 	    ignore = thispage != 1;
@@ -1143,7 +1104,7 @@ continuepage:
 		}
 	    } else if (doc->pages[doc->numpages].media == NULL &&
 		       iscomment(line+2, "PageMedia:")) {
-		cp = gettext(line+length("%%PageMedia:"), NULL);
+		cp = ps_gettext(line+length("%%PageMedia:"), NULL);
 		for (dmp = doc->media, i=0; i<doc->nummedia; i++, dmp++) {
 		    if (strcmp(cp, dmp->name) == 0) {
 			doc->pages[doc->numpages].media = dmp;
@@ -1153,7 +1114,7 @@ continuepage:
 		PS_free(cp);
 	    } else if (doc->pages[doc->numpages].media == NULL &&
 		       iscomment(line+2, "PaperSize:")) {
-		cp = gettext(line+length("%%PaperSize:"), NULL);
+		cp = ps_gettext(line+length("%%PaperSize:"), NULL);
 		for (dmp = doc->media, i=0; i<doc->nummedia; i++, dmp++) {
 		    /* Note: Paper size comment uses down cased paper size
 		     * name.  Case insensitive compares are only used for
@@ -1175,8 +1136,10 @@ continuepage:
 			    &(doc->pages[doc->numpages].boundingbox[LLX]),
 			    &(doc->pages[doc->numpages].boundingbox[LLY]),
 			    &(doc->pages[doc->numpages].boundingbox[URX]),
-			    &(doc->pages[doc->numpages].boundingbox[URY])) == 4)
+			    &(doc->pages[doc->numpages].boundingbox[URY])) == 4) 
+		      {
 			if (page_bb_set == NONE) page_bb_set = 1;
+		      }
 		    else {
 			float fllx, flly, furx, fury;
 			if (sscanf(line+length("%%PageBoundingBox:"),
@@ -1229,7 +1192,7 @@ continuepage:
 	if (!DSCcomment(line)) {
 	    /* Do nothing */
 	} else if (iscomment(line+2, "Page:")) {
-	    PS_free(gettext(line+length("%%Page:"), &next_char));
+	    PS_free(ps_gettext(line+length("%%Page:"), &next_char));
 	    if (sscanf(next_char, "%d", &thispage) != 1) thispage = 0;
 	    if (!ignore && thispage == nextpage) {
 		if (doc->numpages > 0) {
@@ -1322,7 +1285,7 @@ continuepage:
 	if (!preread) section_len += line_len;
 	preread = 0;
 	if (DSCcomment(line) && iscomment(line+2, "Page:")) {
-	    PS_free(gettext(line+length("%%Page:"), &next_char));
+	    PS_free(ps_gettext(line+length("%%Page:"), &next_char));
 	    if (sscanf(next_char, "%d", &thispage) != 1) thispage = 0;
 	    if (!ignore && thispage == nextpage) {
 		if (doc->numpages > 0) {
@@ -1383,7 +1346,7 @@ psfree(doc)
 /*
  * gettextline -- skip over white space and return the rest of the line.
  *               If the text begins with '(' return the text string
- *		 using gettext().
+ *		 using ps_gettext().
  */
 /*----------------------------------------------------------*/
 
@@ -1397,7 +1360,7 @@ gettextline(line)
     while (*line && (*line == ' ' || *line == '\t')) line++;
     if (*line == '(') {
         ENDMESSAGE(gettextline)
-	return gettext(line, NULL);
+	return ps_gettext(line, NULL);
     } else {
 	if (strlen(line) == 0) {ENDMESSAGE(gettextline) return NULL;}
 	cp = (char *) PS_malloc(strlen(line));
@@ -1411,13 +1374,13 @@ gettextline(line)
 
 /*----------------------------------------------------------*/
 /*
- *	gettext -- return the next text string on the line.
- *		   return NULL if nothing is present.
+ *	ps_gettext -- return the next text string on the line.
+ *		      return NULL if nothing is present.
  */
 /*----------------------------------------------------------*/
 
 static char *
-gettext(line, next_char)
+ps_gettext(line, next_char)
     char *line;
     char **next_char;
 {
@@ -1425,7 +1388,7 @@ gettext(line, next_char)
     char *cp;
     int quoted=0;
 
-    BEGINMESSAGE(gettext)
+    BEGINMESSAGE(ps_gettext)
     while (*line && (*line == ' ' || *line == '\t')) line++;
     cp = text;
     if (*line == '(') {
@@ -1433,6 +1396,8 @@ gettext(line, next_char)
 	quoted=1;
 	line++;
 	while (*line && !(*line == ')' && level == 0 )) {
+	    if (cp - text >= PSLINELENGTH - 1)
+                break;
 	    if (*line == '\\') {
 		if (*(line+1) == 'n') {
 		    *cp++ = '\n';
@@ -1485,18 +1450,26 @@ gettext(line, next_char)
 	    } else {
 		*cp++ = *line++;
 	    }
-	}
+        }
+        /* Delete trailing ')' */
+        if (*line)
+          {
+            *line++;
+          }
     } else {
-	while (*line && !(*line == ' ' || *line == '\t' || *line == '\n'))
+        while (*line && !(*line == ' ' || *line == '\t' || *line == '\n')) {
+            if (cp - text >= PSLINELENGTH - 2)
+                break;
 	    *cp++ = *line++;
+	}
     }
     *cp = '\0';
     if (next_char) *next_char = line;
-    if (!quoted && strlen(text) == 0) {ENDMESSAGE(gettext) return NULL;}
+    if (!quoted && strlen(text) == 0) {ENDMESSAGE(ps_gettext) return NULL;}
     cp = (char *) PS_malloc(strlen(text)+1);
     CHECK_MALLOCED(cp);
     strcpy(cp, text);
-    ENDMESSAGE(gettext)
+    ENDMESSAGE(ps_gettext)
     return cp;
 }
 
@@ -1699,14 +1672,8 @@ static char * ps_io_fgetchars(fd,num)
       }
 
       FD_LINE_END = FD_BUF_END;
-#ifdef VMS
-      /* different existing VMS file formats require that we use read here ###jp###,10/12/96 */ 
-      if (num<0) FD_BUF_END += read(FD_FILE_DESC,FD_BUF+FD_BUF_END,LINE_CHUNK_SIZE);
-      else       FD_BUF_END += fread(FD_BUF+FD_BUF_END,size_of_char,LINE_CHUNK_SIZE,FD_FILE);
-#else
       /* read() seems to fail sometimes (? ? ?) so we always use fread ###jp###,07/31/96*/
       FD_BUF_END += fread(FD_BUF+FD_BUF_END,size_of_char,LINE_CHUNK_SIZE,FD_FILE);
-#endif
 
       FD_BUF[FD_BUF_END] = '\0';
       if (FD_BUF_END-FD_LINE_END == 0) {
@@ -1791,6 +1758,8 @@ static char * readline (fd, lineP, positionP, line_lenP)
            (DSCcomment(line) && iscomment(line+2,(comment)))
 #define IS_BEGIN(comment)				\
            (iscomment(line+7,(comment)))
+#define IS_END(comment)				\
+           (iscomment(line+5,(comment)))
 #define SKIP_WHILE(cond)				\
 	   while (readline(fd, &line, NULL, &nbytes) && (cond)) *line_lenP += nbytes;\
            skipped=1;
@@ -1826,7 +1795,12 @@ static char * readline (fd, lineP, positionP, line_lenP)
    else
 #endif
    if  (!IS_COMMENT("Begin"))     {} /* Do nothing */
-   else if IS_BEGIN("Document:")  SKIP_UNTIL_1("EndDocument")
+   else if IS_BEGIN("Document:")  {  /* Skip the EPS without handling its content */
+            while (line && !IS_END("Document")) {
+               line = ps_io_fgetchars(fd,-1);
+               if (line) *line_lenP += FD_LINE_LEN;
+            }
+   }
    else if IS_BEGIN("Feature:")   SKIP_UNTIL_1("EndFeature")
 #ifdef USE_ACROREAD_WORKAROUND
    else if IS_BEGIN("File")       SKIP_UNTIL_2("EndFile","EOF")
